==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/language/japanese/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.8.4.2 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp login block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","");
define("_MB_XOONIPS_ITEM_ALL_LABEL","");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","ȥ & ");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","Ͽ");
define("_MB_XOONIPS_ACCOUNT_LPASS","ѥʶ");
define("_MB_XOONIPS_ACCOUNT_USERNAME","桼 ID");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","ѥ");
define("_MB_XOONIPS_ACCOUNT_LOGIN","");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "Ⱦ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "Խ" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "롼װ" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "ƥ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "ץ饤١ȥĥ꡼Խ" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "ܺٸ" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "ƥϿ" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "᥿ǡ" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "ݡ" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "롼Խ" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "롼׸ƥྵǧ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "롼ץĥ꡼Խ" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "롼Խ" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "桼ǧ" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "ƥྵǧ" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "ĥ꡼Խ" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "٥ȥ" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "ݡ" );

?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/language/japanese/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.16 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp search block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","");
define("_MB_XOONIPS_ITEM_ADVANCED_SEARCH_LABEL","ܺٸ");
define("_MB_XOONIPS_ITEM_ALL_LABEL","");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","ȥ & ");
define("_MB_XOONIPS_ITEM_METADATA_LABEL","᥿ǡ");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","Ͽ");
define("_MB_XOONIPS_ACCOUNT_LPASS","ѥʶ");
define("_MB_XOONIPS_ACCOUNT_USERNAME","桼 ID");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","ѥ");
define("_MB_XOONIPS_ACCOUNT_LOGIN","");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "Ⱦ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "Խ" );
define("_MB_XOONIPS_ACCOUNT_SHOW_USERS", "桼" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "롼װ" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "ƥ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "ץ饤١ȥĥ꡼Խ" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "ܺٸ" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "ƥϿ" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "᥿ǡ" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "ݡ" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "롼Խ" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "롼׸ƥྵǧ" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "롼ץĥ꡼Խ" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "롼Խ" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "桼ǧ" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "ƥྵǧ" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "ĥ꡼Խ" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "٥ȥ" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "ݡ" );

define('_MB_XOONIPS_RANKING_VIEWED_ITEM', 'Ǥ¿줿ƥ ' );
define('_MB_XOONIPS_RANKING_DOWNLOADED_ITEM', 'Ǥ¿ɤ줿ƥ' );
define('_MB_XOONIPS_RANKING_CONTRIBUTING_USER', 'Ǥ¿ƥ桼' );
define('_MB_XOONIPS_RANKING_SEARCHED_KEYWORD', 'Ǥ¿줿 ' );
define('_MB_XOONIPS_RANKING_CONTRIBUTED_GROUP', 'Ǥ赤Τ륰롼' );

define('_MB_XOONIPS_RANKING_NEW_ITEM', '奢ƥ' );
define('_MB_XOONIPS_RANKING_NEW_GROUP', '奰롼' );
define("_MB_XOONIPS_RANKING_EMPTY", "󥭥󥰤Ǥ"); 
define("_MB_XOONIPS_RANKING_RANK_STR", ""); 

define("_MB_XOONIPS_SU_START", "su򳫻Ϥ"); 
define("_MB_XOONIPS_SU_END", "su (<b>%s</b>) λ"); 

?>
